@@ -5,23 +5,27 @@ from lxml import etree
 
 
 class Attributes(object):
-    def __init__(self, string, attributes):
-        self.string = string
+    def __init__(self, data, attributes):
+        self.data       = data
         self.attributes = attributes
 
-    def __pytoxml__(self, structure, element, name):
+    def __pytoxml__(self, structure, element, name, pytoxml):
+
         for key, value in self.attributes.items():
             element.set(key, value)
 
-        if self.string:
-            element.text = self.string
+        if self.data:
+            if isinstance(self.data, DictType):
+                pytoxml.type_builder_dict(self.data, element, name, pytoxml)
+            else:
+                element.text = self.data
 
 
 class CData(object):
     def __init__(self, string):
         self.string = string
 
-    def __pytoxml__(self, structure, element, name):
+    def __pytoxml__(self, structure, element, name, pytoxml):
         element.text = etree.CDATA(unicode(self.string))
 
 
@@ -59,23 +63,23 @@ class PyToXml(object):
         logic."""
         return "item"
 
-    def type_builder_list(self, structure, element, name):
+    def type_builder_list(self, structure, element, name, pytoxml):
         for value in structure:
             sub = etree.SubElement(element, self.pluralisation(name))
             self.traverse(value, sub, name)
 
-    def type_builder_string(self, structure, element, name):
+    def type_builder_string(self, structure, element, name, pytoxml):
         element.text = structure
 
-    def type_builder_dict(self, structure, element, name):
+    def type_builder_dict(self, structure, element, name, pytoxml):
         for key, value in structure.iteritems():
             sub = etree.SubElement(element, key)
             self.traverse(value, sub, key)
 
-    def type_builder_number(self, structure, element, name):
+    def type_builder_number(self, structure, element, name, pytoxml):
         element.text = str(structure)
 
-    def type_builder_bool(self, structure, element, name):
+    def type_builder_bool(self, structure, element, name, pytoxml):
         element.text = str(structure).lower()
 
     def add_type_handler(self, typ, handler=None):
@@ -116,7 +120,7 @@ class PyToXml(object):
             else:
                 raise TypeError("Don't know how to serialise %s." % typ)
 
-        return processor(structure, element, name)
+        return processor(structure, element, name, self)
 
     def encode(self):
         """Encode the structure passed into the constructor as
